@@ -13,10 +13,6 @@ use byteorder::ReadBytesExt;
 use std::io::{Read, Take};
 use std::cmp;
 
-// Expose C api wrapper.
-pub mod capi;
-pub use capi::*;
-
 mod boxes;
 use boxes::BoxType;
 
@@ -109,7 +105,7 @@ struct FileTypeBox {
 /// Movie header box 'mvhd'.
 #[derive(Debug)]
 struct MovieHeaderBox {
-    timescale: u32,
+    pub timescale: u32,
     duration: u64,
 }
 
@@ -217,7 +213,7 @@ pub enum AudioCodecSpecific {
 #[derive(Debug, Clone)]
 pub struct AudioSampleEntry {
     data_reference_index: u16,
-    channelcount: u16,
+    pub channelcount: u16,
     pub samplesize: u16,
     pub samplerate: u32,
     pub codec_specific: AudioCodecSpecific,
@@ -273,6 +269,7 @@ pub struct OpusSpecificBox {
 #[derive(Debug, Default)]
 pub struct MediaContext {
     pub timescale: Option<MediaTimeScale>,
+    pub has_mvex: bool,
     /// Tracks found in the file.
     pub tracks: Vec<Track>,
 }
@@ -310,6 +307,21 @@ pub struct TrackTimeScale(pub u64, pub usize);
 #[derive(Debug, Copy, Clone, PartialEq)]
 pub struct TrackScaledTime(pub u64, pub usize);
 
+/// A fragmented file contains no sample data in stts, stsc, and stco.
+#[derive(Debug, Default)]
+pub struct EmptySampleTableBoxes {
+    pub empty_stts : bool,
+    pub empty_stsc : bool,
+    pub empty_stco : bool,
+}
+
+/// Check boxes contain data.
+impl EmptySampleTableBoxes {
+    pub fn all_empty(&self) -> bool {
+        self.empty_stts & self.empty_stsc & self.empty_stco
+    }
+}
+
 #[derive(Debug, Default)]
 pub struct Track {
     id: usize,
@@ -318,8 +330,9 @@ pub struct Track {
     pub media_time: Option<TrackScaledTime>,
     pub timescale: Option<TrackTimeScale>,
     pub duration: Option<TrackScaledTime>,
-    track_id: Option<u32>,
+    pub track_id: Option<u32>,
     pub mime_type: String,
+    pub empty_sample_boxes: EmptySampleTableBoxes,
     pub data: Option<SampleEntry>,
     pub tkhd: Option<TrackHeaderBox>, // TODO(kinetik): find a nicer way to export this.
 }
@@ -523,6 +536,10 @@ fn read_moov<T: Read>(f: &mut BMFFBox<T>, context: &mut MediaContext) -> Result<
                 try!(read_trak(&mut b, &mut track));
                 context.tracks.push(track);
             }
+            BoxType::MovieExtendsBox => {
+                context.has_mvex = true;
+                try!(skip_box_content(&mut b));
+            }
             _ => try!(skip_box_content(&mut b)),
         };
         check_parser_state!(b.content);
@@ -644,10 +661,12 @@ fn read_stbl<T: Read>(f: &mut BMFFBox<T>, track: &mut Track) -> Result<()> {
             }
             BoxType::TimeToSampleBox => {
                 let stts = try!(read_stts(&mut b));
+                track.empty_sample_boxes.empty_stts = stts.samples.is_empty();
                 log!("{:?}", stts);
             }
             BoxType::SampleToChunkBox => {
                 let stsc = try!(read_stsc(&mut b));
+                track.empty_sample_boxes.empty_stsc = stsc.samples.is_empty();
                 log!("{:?}", stsc);
             }
             BoxType::SampleSizeBox => {
@@ -656,6 +675,7 @@ fn read_stbl<T: Read>(f: &mut BMFFBox<T>, track: &mut Track) -> Result<()> {
             }
             BoxType::ChunkOffsetBox => {
                 let stco = try!(read_stco(&mut b));
+                track.empty_sample_boxes.empty_stco = stco.offsets.is_empty();
                 log!("{:?}", stco);
             }
             BoxType::ChunkLargeOffsetBox => {
